==> dl.php?src=linea21_1_6.zip: linea21/languages/en/lang_workshoprep.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['workshoprep']['section'] = "workgroups reports";

/*	nommage des modules
 *  	*/
$lang['workshoprep']['name']='report';
$lang['workshoprep']['confirm_add'] = "Report successfully added\n";
$lang['workshoprep']['confirm_mod'] = "Report successfully updated\n";
$lang['workshoprep']['confirm_sup'] ="Report successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['workshoprep']['add']= 'Add a new '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod']= 'Edit '.$lang['workshoprep']['name'];
$lang['workshoprep']['sup']= 'Delete '.$lang['workshoprep']['name'];
$lang['workshoprep']['det']= ucfirst($lang['workshoprep']['name']). ' details';
$lang['workshoprep']['return_workshop']= 'Back to workgroup';


/*	public
 *  	*/
$lang['workshoprep']['name2']='report details';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['workshoprep']['add_title']='Add data about the new '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod_title']='Edit data about '.$lang['workshoprep']['name'];


/*	check integrité des données
 *  	*/
$lang['workshoprep']['no_title'] = 'Title is required.';
$lang['workshoprep']['no_resume'] = 'Summary is required.';


/*	nommage élément rubrique
 *  	*/
$lang['workshoprep']['title']='title';
$lang['workshoprep']['resume']='summary';
$lang['workshoprep']['workshop_product']='produced by workgroup';

$lang['workshoprep']['statut']='status';
$lang['workshoprep']['comment']='comment';

$lang['workshoprep']['published_on']='published on';
$lang['workshoprep']['not_published']='not published';

$lang['workshoprep']['generals']='global informations';
$lang['workshoprep']['parts']='report\'s content parts';
$lang['workshoprep']['link_res']='report links';
$lang['workshoprep']['biblio_res']='report bibliographical notices';


/*	nommage quickbox
 *  	*/
$lang['workshoprep']['qb_titleadd']=' latest additions';
$lang['workshoprep']['qb_titlemod']=' latest modifications';
$lang['workshoprep']['qb_titlesup']=' latest deletions';
$lang['workshoprep']['qb_titlepubli']=' latest publications';


/*	divers
 *  	*/
$lang['workshoprep']['description']='description';
$lang['workshoprep']['part_number']='part ';


/*	messages
 *  	*/
$lang['workshoprep']['add_new_part']="Add a new part to this report";
$lang['workshoprep']['add_new_linkres']="Add a new link to this report";
$lang['workshoprep']['add_new_bibliores']="Add a new bibliographical notice to this report";

$lang['workshoprep']['no_link']="There is no website in this report";
$lang['workshoprep']['del_link']="Delete this link";
$lang['workshoprep']['mod_link']="Edit this link";

$lang['workshoprep']['no_biblio']="There is no bibliographical notice in this report";
$lang['workshoprep']['del_biblio']="Delete this bibliographical notice";
$lang['workshoprep']['mod_biblio']="Edit this bibliographical notice";

$lang['workshoprep']['no_part']="There is no part in this report";
$lang['workshoprep']['del_part']="Delete this part";
$lang['workshoprep']['mod_part']="Edit this part";






/*	rubrique d'aide

*  	*/
$lang['workshoprep']['help_add1']='To add a new report, please insert the required informations in the form above';
$lang['workshoprep']['help_add2']='After submitting the form, check your data in the summary';
$lang['workshoprep']['help_add3']='After checking summary, click the \'review settings\' button to make new changes';

$lang['workshoprep']['help_mod1']='To edit a report, please insert the required informations in the form above';
$lang['workshoprep']['help_mod2']='Once the form submitted, check your data in the summary';
$lang['workshoprep']['help_mod3']='After checking summary, click the \'review settings\' button to make new changes';


$lang['workshoprep']['help_det1']='Edit report by clicking on the edit icon linked in';
$lang['workshoprep']['help_det2']='Delete report by clicking on the delete icon linked in';
$lang['workshoprep']['help_det3']='Click on report titles to display more informations';
$lang['workshoprep']['help_det4']='Click on the related icons to add, delete or update a report';

$lang['workshoprep']['help_sup1']='Click cancel to abort deletion';


?>

==> dl.php?src=linea21_1_8.zip: linea21/languages/en/lang_workshoprep.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['workshoprep']['section'] = "workgroups reports";

/*	nommage des modules
 *  	*/
$lang['workshoprep']['name']='report';
$lang['workshoprep']['confirm_add'] = "Report successfully added\n";
$lang['workshoprep']['confirm_mod'] = "Report successfully updated\n";
$lang['workshoprep']['confirm_sup'] ="Report successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['workshoprep']['add']= 'Add a new '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod']= 'Edit '.$lang['workshoprep']['name'];
$lang['workshoprep']['sup']= 'Delete '.$lang['workshoprep']['name'];
$lang['workshoprep']['det']= ucfirst($lang['workshoprep']['name']). ' details';
$lang['workshoprep']['return_workshop']= 'Back to workgroup';


/*	public
 *  	*/
$lang['workshoprep']['name2']='Summary';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['workshoprep']['add_title']='Add data about the new '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod_title']='Edit data about '.$lang['workshoprep']['name'];


/*	check integrité des données
 *  	*/
$lang['workshoprep']['no_title'] = 'Title is required.';
$lang['workshoprep']['no_resume'] = 'Summary is required.';


/*	nommage élément rubrique
 *  	*/
$lang['workshoprep']['title']='title';
$lang['workshoprep']['resume']='summary';
$lang['workshoprep']['workshop_product']='produced by workgroup';

$lang['workshoprep']['statut']='status';
$lang['workshoprep']['comment']='comment';

$lang['workshoprep']['published_on']='published on';
$lang['workshoprep']['not_published']='not published';

$lang['workshoprep']['generals']='global informations';
$lang['workshoprep']['parts']='report\'s content parts';
$lang['workshoprep']['link_res']='associated links';
$lang['workshoprep']['biblio_res']='associated bibliography';


/*	nommage quickbox
 *  	*/
$lang['workshoprep']['qb_titleadd']=' latest additions';
$lang['workshoprep']['qb_titlemod']=' latest modifications';
$lang['workshoprep']['qb_titlesup']=' latest deletions';
$lang['workshoprep']['qb_titlepubli']=' latest publications';


/*	divers
 *  	*/
$lang['workshoprep']['description']='description';
$lang['workshoprep']['part_number']='part ';


/*	messages
 *  	*/
$lang['workshoprep']['add_new_part']="Add a new part to this report";
$lang['workshoprep']['add_new_linkres']="Add a new link to this report";
$lang['workshoprep']['add_new_bibliores']="Add a new bibliographical notice to this report";

$lang['workshoprep']['no_link']="There is no website in this report";
$lang['workshoprep']['del_link']="Delete this link";
$lang['workshoprep']['mod_link']="Edit this link";

$lang['workshoprep']['no_biblio']="There is no bibliographical notice in this report";
$lang['workshoprep']['del_biblio']="Delete this bibliographical notice";
$lang['workshoprep']['mod_biblio']="Edit this bibliographical notice";

$lang['workshoprep']['no_part']="There is no part in this report";
$lang['workshoprep']['del_part']="Delete this part";
$lang['workshoprep']['mod_part']="Edit this part";






/*	rubrique d'aide

*  	*/
$lang['workshoprep']['help_add1']='To add a new report, please insert the required informations in the form above';
$lang['workshoprep']['help_add2']='After submitting the form, check your data in the summary';
$lang['workshoprep']['help_add3']='After checking summary, click the \'review settings\' button to make new changes';

$lang['workshoprep']['help_mod1']='To edit a report, please insert the required informations in the form above';
$lang['workshoprep']['help_mod2']='Once the form submitted, check your data in the summary';
$lang['workshoprep']['help_mod3']='After checking summary, click the \'review settings\' button to make new changes';


$lang['workshoprep']['help_det1']='Edit report by clicking on the edit icon linked in';
$lang['workshoprep']['help_det2']='Delete report by clicking on the delete icon linked in';
$lang['workshoprep']['help_det3']='Click on report titles to display more informations';
$lang['workshoprep']['help_det4']='Click on the related icons to add, delete or update a report';

$lang['workshoprep']['help_sup1']='Click cancel to abort deletion';


?>
